@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -718,7 +718,7 @@ miner_started (TrackerMiner *miner)
 
 	g_object_set (miner,
 	              "progress", 0.0,
-	              "status", _("Initializing"),
+	              "status", "Initializing",
 	              NULL);
 
 	crawl_directories_start (fs);
@@ -729,7 +729,7 @@ miner_stopped (TrackerMiner *miner)
 {
 	g_object_set (miner,
 	              "progress", 1.0,
-	              "status", _("Idle"),
+	              "status", "Idle",
 	              NULL);
 }
 
@@ -883,7 +883,7 @@ process_stop (TrackerMinerFS *fs)
 
 	g_object_set (fs,
 	              "progress", 1.0,
-	              "status", _("Idle"),
+	              "status", "Idle",
 	              NULL);
 
 	g_signal_emit (fs, signals[FINISHED], 0,
@@ -1997,10 +1997,10 @@ item_queue_handlers_set_up (TrackerMinerFS *fs)
 
 	g_object_get (fs, "status", &status, NULL);
 
-	if (g_strcmp0 (status, _("Processing files")) != 0) {
+	if (g_strcmp0 (status, "Processing…") != 0) {
 		/* Don't spam this */
-		g_message ("Processing files...");
-		g_object_set (fs, "status", _("Processing files"), NULL);
+		g_message ("Processing…");
+		g_object_set (fs, "status", "Processing…", NULL);
 	}
 
 	g_free (status);
@@ -2330,24 +2330,27 @@ crawler_check_directory_cb (TrackerCrawler *crawler,
                             gpointer        user_data)
 {
 	TrackerMinerFS *fs = user_data;
-	gboolean should_check, should_change_index;
+	gboolean should_check;
 
 	should_check = should_check_file (fs, file, TRUE);
-	should_change_index = should_change_index_for_file (fs, file);
-
-	if (!should_change_index) {
-		/* Mark the file as ignored, we still want the crawler
-		 * to iterate over its contents, but the directory hasn't
-		 * actually changed, hence this flag.
-		 */
-		g_object_set_qdata (G_OBJECT (file),
-		                    fs->private->quark_ignore_file,
-		                    GINT_TO_POINTER (TRUE));
-	}
 
 	if (!should_check) {
 		/* Remove monitors if any */
 		tracker_monitor_remove (fs->private->monitor, file);
+	} else {
+                gboolean should_change_index;
+
+		should_change_index = should_change_index_for_file (fs, file);
+
+		if (!should_change_index) {
+			/* Mark the file as ignored, we still want the crawler
+			 * to iterate over its contents, but the directory hasn't
+			 * actually changed, hence this flag.
+			 */
+			g_object_set_qdata (G_OBJECT (file),
+			                    fs->private->quark_ignore_file,
+			                    GINT_TO_POINTER (TRUE));
+		}
 	}
 
 	/* We _HAVE_ to check ALL directories because mtime updates
@@ -2550,14 +2553,18 @@ crawl_directories_cb (gpointer user_data)
 	path = g_file_get_path (fs->private->current_directory->file);
 
 	if (fs->private->current_directory->recurse) {
-		str = g_strdup_printf (_("Crawling recursively directory '%s'"), path);
+		str = g_strdup_printf ("Crawling recursively directory '%s'", path);
 	} else {
-		str = g_strdup_printf (_("Crawling single directory '%s'"), path);
+		str = g_strdup_printf ("Crawling single directory '%s'", path);
 	}
 
 	g_message ("%s", str);
 
-	g_object_set (fs, "status", str, NULL);
+	/* Always set the progress here to at least 1% */
+	g_object_set (fs,
+	              "progress", 0.01,
+	              "status", str,
+	              NULL);
 	g_free (str);
 	g_free (path);
 
